@@ -1,5 +1,7 @@
 from .adgroups import AdGroups
 from .bidrecommendations import BidRecommendations
+from .budget_recommendations import BudgetRecommendations
+from .budget_rules_recommendation import BudgetRulesRecommendation
 from .campaigns import Campaigns
 from .campaign_negative_keywords import CampaignNegativeKeywords
 from .keywords import Keywords
